@@ -168,38 +168,38 @@ use constant {
     T_String => 163,
     T_RawString => 164,
     T_ExecString => 165,
-    T_HereDocumentTag => 166,
-    T_HereDocumentRawTag => 167,
-    T_RawHereDocument => 168,
-    T_HereDocument => 169,
-    T_HereDocumentEnd => 170,
-    T_FormatDecl => 171,
-    T_Format => 172,
-    T_FormatEnd => 173,
-    T_Object => 174,
-    T_RegExp => 175,
-    T_Array => 176,
-    T_Hash => 177,
-    T_Operator => 178,
-    T_LocalVar => 179,
-    T_LocalArrayVar => 180,
-    T_LocalHashVar => 181,
-    T_GlobalVar => 182,
-    T_GlobalArrayVar => 183,
-    T_GlobalHashVar => 184,
-    T_ArrayRef => 185,
-    T_HashRef => 186,
-    T_ArrayAt => 187,
-    T_HashAt => 188,
-    T_ArraySet => 189,
-    T_HashSet => 190,
-    T_Function => 191,
-    T_Call => 192,
-    T_Argument => 193,
-    T_List => 194,
-    T_Default => 195,
-    T_Undefined => 196,
-
+    T_VersionString => 166,
+    T_HereDocumentTag => 167,
+    T_HereDocumentRawTag => 168,
+    T_RawHereDocument => 169,
+    T_HereDocument => 170,
+    T_HereDocumentEnd => 171,
+    T_FormatDecl => 172,
+    T_Format => 173,
+    T_FormatEnd => 174,
+    T_Object => 175,
+    T_RegExp => 176,
+    T_Array => 177,
+    T_Hash => 178,
+    T_Operator => 179,
+    T_LocalVar => 180,
+    T_LocalArrayVar => 181,
+    T_LocalHashVar => 182,
+    T_GlobalVar => 183,
+    T_GlobalArrayVar => 184,
+    T_GlobalHashVar => 185,
+    T_ArrayRef => 186,
+    T_HashRef => 187,
+    T_ArrayAt => 188,
+    T_HashAt => 189,
+    T_ArraySet => 190,
+    T_HashSet => 191,
+    T_Function => 192,
+    T_Call => 193,
+    T_Argument => 194,
+    T_List => 195,
+    T_Default => 196,
+    T_Undefined => 197
 };
 1;
 
@@ -258,7 +258,6 @@ use constant {
     T_Ref => 36,
     T_Get => 37,
     T_Set => 38,
-    T_Undefined => 39,
-
+    T_Undefined => 39
 };
 1;
